@@ -1,4 +1,5 @@
 import os
+import io
 import random
 from django.core.files.images import ImageFile
 try:
@@ -6,7 +7,7 @@ try:
     PIL_INSTALLED = True
 except ImportError:
     PIL_INSTALLED = False
-from tempfile import mkstemp
+from tempfile import NamedTemporaryFile
 
 from sampledatahelper.exceptions import ParameterError, NotChoicesFound
 
@@ -23,7 +24,11 @@ class ImageMixin(object):
             raise NotChoicesFound('Not valid images found in directory_path for valid_extensions')
 
         random_path = os.path.join(directory_path, random.choice(list_of_images))
-        im_file = ImageFile(open(random_path, 'r'))
+
+        fd = open(random_path, 'rb')
+        stream = io.BytesIO(fd.read())
+        fd.close()
+        im_file = ImageFile(stream)
         return im_file
 
     def image(self, width, height, typ="simple"):
@@ -48,10 +53,14 @@ class ImageMixin(object):
 
         im = generator.generate(self, width, height)
 
-        tf, tfname = mkstemp(suffix=".png")
+        tf = NamedTemporaryFile(delete=False, suffix=".png")
+        tf.close()
 
-        im.save(tfname)
-
-        im_file = ImageFile(open(tfname, 'rb'))
+        im.save(tf.name)
 
+        fd = open(tf.name, 'rb')
+        stream = io.BytesIO(fd.read())
+        fd.close()
+        im_file = ImageFile(stream)
+        os.unlink(tf.name)
         return im_file
